@@ -1,5 +1,4 @@
 import sys
-import unittest2 as unittest
 
 from datetime import timedelta
 
@@ -12,6 +11,7 @@ from celery.utils import gen_unique_id
 from celery.datastructures import ExceptionInfo
 
 from djcelery.backends.cache import CacheBackend
+from djcelery.tests.utils import unittest
 
 
 class SomeClass(object):
