@@ -1,6 +1,4 @@
 # -*- coding: utf-8 -*-
-import unittest2 as unittest
-
 from django.core import cache
 
 from celery.utils import gen_unique_id
@@ -8,6 +6,8 @@ from celery.decorators import task as task_dec
 
 from celery.tests.test_worker_job import jail
 
+from djcelery.tests.utils import unittest
+
 
 @task_dec()
 def mytask(i, **kwargs):
